==> haskell-hspec-hedgehog-0.0.1.2-365-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hspec-hedgehog.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hspec-hedgehog
version:              0.0.1.2
visibility:           public
id:                   hspec-hedgehog-0.0.1.2-6zIEJ9fFjZOCrj3BRV5S05
key:                  hspec-hedgehog-0.0.1.2-6zIEJ9fFjZOCrj3BRV5S05
license:              BSD-3-Clause
copyright:            2020 Matt Parsons
maintainer:           parsonsmatt@gmail.com
author:               Matt Parsons
homepage:             https://github.com/parsonsmatt/hspec-hedgehog#readme
synopsis:             Integrate Hedgehog and Hspec!
description:
    Please see the README on GitHub at <https://github.com/parsonsmatt/hspec-hedgehog#readme>

category:             Testing
abi:                  a6b52548beda90674f2708c5ec6546b1
exposed:              True
exposed-modules:      Test.Hspec.Hedgehog
import-dirs:          /usr/lib/ghc-9.6.6/site-local/hspec-hedgehog-0.0.1.2
library-dirs:         /usr/lib/ghc-9.6.6/site-local/hspec-hedgehog-0.0.1.2
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/hspec-hedgehog-0.0.1.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hspec-hedgehog
hs-libraries:         HShspec-hedgehog-0.0.1.2-6zIEJ9fFjZOCrj3BRV5S05
depends:
    HUnit-1.6.2.0-E9thsnykSZzAJrramSPMCv
    QuickCheck-2.15.0.1-JsWG6I4IuTa3MyVRCp1l9o base-4.18.2.1
    hedgehog-1.5-8lObE7OX3bh5R3tbC4I5aa
    hspec-2.11.4-DEFaYWQLD7J9ehh1RD63de
    hspec-core-2.11.4-9mULEbTUzoNHd1Kj5nWNTb
    splitmix-0.1.2-3pUksX9j7eDIKtiUvRQofM

haddock-interfaces:
    /usr/share/doc/haskell-hspec-hedgehog/html/hspec-hedgehog.haddock

haddock-html:         /usr/share/doc/haskell-hspec-hedgehog/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hspec-hedgehog-0.0.1.2-366-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hspec-hedgehog.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hspec-hedgehog
version:              0.0.1.2
visibility:           public
id:                   hspec-hedgehog-0.0.1.2-4VjUoO2PVZkjnfWjcuGpl
key:                  hspec-hedgehog-0.0.1.2-4VjUoO2PVZkjnfWjcuGpl
license:              BSD-3-Clause
copyright:            2020 Matt Parsons
maintainer:           parsonsmatt@gmail.com
author:               Matt Parsons
homepage:             https://github.com/parsonsmatt/hspec-hedgehog#readme
synopsis:             Integrate Hedgehog and Hspec!
description:
    Please see the README on GitHub at <https://github.com/parsonsmatt/hspec-hedgehog#readme>

category:             Testing
abi:                  0835d0847d58949e3e15dc21817b7824
exposed:              True
exposed-modules:      Test.Hspec.Hedgehog
import-dirs:          /usr/lib/ghc-9.6.6/site-local/hspec-hedgehog-0.0.1.2
library-dirs:         /usr/lib/ghc-9.6.6/site-local/hspec-hedgehog-0.0.1.2
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/hspec-hedgehog-0.0.1.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hspec-hedgehog
hs-libraries:         HShspec-hedgehog-0.0.1.2-4VjUoO2PVZkjnfWjcuGpl
depends:
    HUnit-1.6.2.0-DydRkK1Ty562EFYgxreweA
    QuickCheck-2.15.0.1-3qjshr9DgdW3qKiQXq7Lfs base-4.18.2.1
    hedgehog-1.5-5KGiDfISdWzBbGoyyXFhaP
    hspec-2.11.4-3Oa94i2aSFlFG3qV0JnWlf
    hspec-core-2.11.4-3f7Mt8RUVHz9XZofgRYiIp
    splitmix-0.1.3-4yNog4w8PX7Ib6rwgNB1AE

haddock-interfaces:
    /usr/share/doc/haskell-hspec-hedgehog/html/hspec-hedgehog.haddock

haddock-html:         /usr/share/doc/haskell-hspec-hedgehog/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
